#!/bin/sh
#   Copyright (c) 2010 digitalSTROM.org, Zurich, Switzerland
#
#   Author: Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
#
#   This file is part of digitalSTROM Server.
#
#   funclib.sh is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   funclib.sh is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this file. If not, see <http://www.gnu.org/licenses/>.

check_in_range() {
    if [[ -z "$1" ]] ; then
        return 1
    fi

    echo $1 | grep "[^0-9]" > /dev/null 2>&1
    if [ "$?" -eq "0" ]; then
        return 1
    fi

    if [[ $1 -lt 0 ]]; then
        return 2
    fi

    if [[ $1 -gt 255 ]]; then
        return 3
    fi

    return 0
}

validate_ip() {
    if [[ -z "$1" ]] ; then
        return 1
    fi

    N1=`echo $1 | cut -d '.' -f 1`

    check_in_range $N1
    if [[ "$?" -ne "0" ]]; then
        return 1
    fi

    N2=`echo $1 | cut -d '.' -f 2`
    check_in_range $N2
    if [[ "$?" -ne "0" ]]; then
        return 1
    fi

    N3=`echo $1 | cut -d '.' -f 3`
    check_in_range $N3
    if [[ "$?" -ne "0" ]]; then
        return 1
    fi
    N4=`echo $1 | cut -d '.' -f 4`
    check_in_range $N4
    if [[ "$?" -ne "0" ]]; then
        return 1
    fi

    if [[ "$N1" -eq "0" ]] && [[ "$N2" -eq "0" ]] &&
       [[ "$N3" -eq "0" ]] && [[ "$N4" -eq "0" ]]; then
        return 1
    fi

    if [[ "$N1" -eq "255" ]] && [[ "$N2" -eq "255" ]] &&
       [[ "$N3" -eq "255" ]] && [[ "$N4" -eq "255" ]]; then
        return 1
    fi

    if [[ "$N1" -eq "0" ]]; then
        return 1
    fi

    if [[ "$N4" -eq "255" ]]; then
        return 1
    fi

    return 0
}

