//= require <timeinfo>
//= require <hostnameform>
//= require <timeform>

Ext.namespace('dSS11', 'dSS11.config', 'dSS11.sys');

dSS11.SysConfigPanel = Ext.extend(Ext.Panel,
    {
        initComponent: function()
        {
            this.restart = new Ext.form.FieldSet(
                {
                    title:  _("Restart digitalSTROM server application"),
                    layout: 'form',
                    items: [
                        {
                            xtype:  'label',
                            ref: 'dssUptime',
                            text: _("dSS is running since") + '...',
                            cls: 'x-green-text',
                            anchor: '100%'
                        },
                        {
                            xtype: 'box',
                            height: 10
                        },
                        {
                            xtype: 'panel',
                            layout: 'hbox',
                            border: false,
                            items:
                            [
                                {
                                    xtype: 'box',
                                    flex: 1
                                },
                                {
                                    xtype: 'button',
                                    text: _("Restart dSS"),
                                    minWidth: 90,
                                    handler: this.restartdSS.createDelegate(this)
                                }
                            ]
                        }
                    ]
                }
            );

            this.reboot = new Ext.form.FieldSet(
                {
                    title:  _("Reboot system"),
                    layout: 'form',
                    items: [
                        {
                            xtype:  'label',
                            ref: 'Uptime',
                            text: _("System is up for") + '...',
                            cls: 'x-green-text',
                            anchor: '100%'
                        },
                        {
                            xtype: 'box',
                            height: 10
                        },
                        {
                            xtype: 'panel',
                            layout: 'hbox',
                            border: false,
                            items:
                            [
                                {
                                    xtype: 'box',
                                    flex: 1
                                },
                                {
                                    xtype: 'button',
                                    text: _("Reboot"),
                                    minWidth: 90,
                                    handler: this.reboot.createDelegate(this)
                                }
                            ]
                        }
                    ]
                }
            );

            Ext.apply(this, {
                hideBorders: true,
                autoScroll: true,
                items: [
                    {
                        xtype: 'dss11syshostnameform',
                        ref: 'nameForm'
                    },
                    {
                        xtype: 'dss11systimeform',
                        ref: 'timeForm'
                    },
                    {
                        padding: 6,
                        xtype: 'panel',
                        bodyBorder: false,
                        width: 400,
                        items: [ this.restart ]
                    },
                    {
                        padding: 6,
                        xtype: 'panel',
                        width: 400,
                        bodyBorder: false,
                        items: [ this.reboot ]
                    }
                ]
            });
            
            dSS11.SysConfigPanel.superclass.initComponent.apply(this, arguments);

           this.on('activate',
                    function() {
                        this.reloadData.defer(1000, this);
                    },
                    this);

        }, // initcomponent
        restartdSS: function() {
            var maskEl = this.findParentByType('viewport').getEl();

            Ext.Msg.show({
                title: _("Restart dSS application"),
                msg: _("Are you sure that you want to restart the dSS application?"),
                    buttons: Ext.Msg.YESNO,
                    scope: this,
                    fn: function(button, text) {
                        if (button == 'yes') {
                            maskEl.mask(_("Restarting dSS application") +
                                          "...", 'x-mask-loading');

                            Ext.Ajax.request({
                                url: '/cgi-bin/restartdss.sh',
                                disableCaching: true,
                                //params: { 'dss' : 'dss' }, // dummy parameter
                                method: 'GET',
                                scope: this,
                                success: function(response) {
                                    maskEl.unmask();
                                    try {
                                        var jsonData = Ext.util.JSON.decode(
                                                response.responseText);

                                        if (jsonData.success !== true) {
                                            Ext.Msg.alert(_("Error"), 
                                                            jsonData.message);
                                            return;
                                        } else {
                                            Ext.Msg.show({
                                                title: _("Info"),
                                                msg: _("digitalSTROM " + 
                                                "server application " + 
                                                "successfully restarted"),
                                                icon: Ext.MessageBox.INFO,
                                                buttons: Ext.Msg.OK
                                            });
                                        }
                                    } catch (error) {
                                        Ext.Msg.alert(_("Error"),
                                            _("digitalSTROM server " + 
                                              "application could not be " + 
                                              "restarted") + ": " + 
                                                error.message);
                                    }
                                    this.restart.dssUptime.doAutoLoad();
                                },
                                failure: function() {
                                    maskEl.unmask();
                                    Ext.Msg.alert(_("Error"),
                                        _("digitalSTROM server " + 
                                          "application could not be " + 
                                          "restarted"));
                                    this.restart.dssUptime.doAutoLoad();
                                }
                            });

                        }
                    },
                    animEl: 'elId',
                    icon: Ext.MessageBox.QUESTION
            });

        },
        rebootWaitMsg: function(secs, w) {
            if (secs > 0) {
                w.updateProgress(1-(secs/dSS11.config.rebootWait), secs + " " +
                        dSS11.config.gt.ngettext("second remaining", 
                                                 "seconds remaining",
                                                  secs));
                secs--;
                this.rebootWaitMsg.defer(1000, this, [secs, w]);
            } else {
                w.hide();
                this.findParentByType(Ext.Viewport).el.mask(_("Reloading page") + "...");
                window.location = window.location.protocol + '//' +
                                  window.location.host;

            }
        },
        reboot: function() {
            var maskEl = this.findParentByType('viewport').getEl();
            Ext.Msg.show({
                title: _("Reboot system"),
                msg: _("Are you sure that you want to reboot the system?") +
                       "<br/>" +
                       _("Note: this will take about a minute"),
                    buttons: Ext.Msg.YESNO,
                    scope: this,
                    fn: function(button, text) {
                        if (button == 'yes') {
                            Ext.Ajax.request({
                                url: '/cgi-bin/rebootwrapper.sh',
                                disableCaching: true,
                                params: { action : 'reboot' },
                                method: 'GET',
                                scope: this,
                                success: function(response) {
                                    try {
                                        var jsonData = Ext.util.JSON.decode(
                                                response.responseText);

                                        if (jsonData.success !== true) {
                                            Ext.Msg.alert(_("Error"), 
                                                            jsonData.message);
                                            maskEl.unmask();
                                            return;
                                        } else {
                                            var w = Ext.Msg.progress(
                                                _("Rebooting system"),
                                                _("Please wait while the " +
                                                  "system is rebooting") + 
                                                  "<br/>" + 
                                                _("The setup page will be " +
                                                  "automatically reloaded " +
                                                  "after the time elapses"));
                                            this.rebootWaitMsg(
                                                    dSS11.config.rebootWait, w);
                                        }
                                    } catch (error) {
                                        Ext.Msg.alert(_("Error"),
                                            _("System reboot could not " + 
                                              "be initiated") + ": " + 
                                                error.message);
                                    }
                                },
                                failure: function() {
                                    Ext.Msg.alert(_("Error"),
                                        _("System reboot could not be " + 
                                          "initiated"));
                                    maskEl.unmask();
                                }
                            });

                        }
                    },
                    animEl: 'elId',
                    icon: Ext.MessageBox.QUESTION
            });
        },
        reloadUptime: function() {
            Ext.Ajax.request({
                url: '/cgi-bin/uptime.sh',
                disableCaching: true,
                method: 'GET',
                scope: this,
                success: function(response) {
                    try {
                        var json = Ext.util.JSON.decode(response.responseText);
                        if (json.success !== true) {
                            Ext.Msg.alert(_("Error"), _(json.message));
                            // unmask
                            return;
                        }
                        
                        var dssMsg;
                        if (json.data.dssrunning !== true) {
                            dssMsg = _("dSS aplication is not running");
                        } else {
                            if (json.data.dssuptime.length > 0) {
                                dssMsg = _("dSS is running since") + ' ' +
                                         json.data.dssuptime;
                            } else {
                                dssMsg = _("dSS application is running");
                            }
                        }
                        this.restart.dssUptime.setText(dssMsg);

                        var dss11Msg;
                        if (json.data.dss11uptime > 0) {
                            dss11Msg = _("System is up for") + ' ' +
                                       json.data.dss11days + ' ' +
                                       _("day", json.data.dss11days) +
                                       ', ' + json.data.dss11hours + ' ' +
                                       _("hour", json.data.dss11hours) +
                                       ' ' + _("and") + ' ' +
                                       json.data.dss11minutes + ' ' +
                                       _("minute", json.data.dss11minutes);
                        } else {
                            dss11Msg = _("Could not determine time since last" +
                                         " boot");
                        }

                        this.reboot.Uptime.setText(dss11Msg);
                    } catch (error) {
                        // unmask
                        Ext.Msg.alert(_("Error"), 
                            _("Cold not determine uptime") + ": " +
                            _(error.message));
                    }
                },
                failure: function() {
                    // unmask
                    Ext.Msg.alert(_("Error"), _("Cold not determine uptime"));
                }
            });
        },
        reloadData: function() {
            this.nameForm.reloadHostName();
            this.timeForm.reloadTimeSettings();
            this.reloadUptime();
        }
    }
);

Ext.reg('dss11sysconfig', dSS11.SysConfigPanel);

