Ext.namespace('dSS11', 'dSS11.config');

dSS11.SystemUpdatePanel = Ext.extend(Ext.Panel,
    {
        initComponent: function()
        {
            this.updateStore = new Ext.data.JsonStore(
                {
                    url: '/cgi-bin/opkgwrapper.sh?action=list-upgradable',
                    root: 'data',
                    fields: 
                    [
                        'name', 'version', 'maintainer', 
                        'description', 'homepage', 'state'
                    ]
                }
            );

            this.loaded = false;
            this.fromRefetch = false;

            var tpl = dSS11.util.defaultIPKTemplate();
            tpl.compile();

            this.mainGrid = new Ext.grid.GridPanel(
                {
                    store: this.updateStore,
                    enableColumnHide: false,
                    enableHdMenu: false,
                    columns:
                    [
                        {
                            xtype: 'templatecolumn',
                            header: _("Available updates"),
                            dataIndex: 'name',
                            sortable: true,

                            tpl: tpl
                        }
                    ],
                    trackMouseOver: false,
                    viewConfig: { forceFit: true },
                    disableSelection: true,
                    bodyBorder: false
                }
            );

            this.noUpdatesTooltip =  new Ext.ToolTip(
                {
                    target: 'dSS11SysUpdateButton',
                    html: '<br/>' + 
                          _("Your system is up to date"),
                    title: _("No updates found"),
                    closable: true,
                    draggable: true,
                    anchor: 'right'
                }
            );

            this.gotUpdatesTooltip = new Ext.ToolTip(
                {
                    target: 'dSS11SysUpdateButton',
                    html: '<br/>' + 
                          _("Updates are available for your system, click the update button to install them"),
                    title: _("Updates found"),
                    closable: true,
                    draggable: true,
                    anchor: 'right'
                }
            );

            Ext.apply(this,
                {
                    layout: 'fit',
                    tbar: [
                        {
                            xtype: 'button',
                            text: _("Check for new updates"),
                            iconCls: 'icon-refresh-feed',
                            scope: this,
                            tooltip: _("Contact the server and check availability of new updates"),
                            handler: this.handleRefetch.createDelegate(this)
                        },
                        {
                            xtype: 'button',
                            text: _("Update system"),
                            ref: 'dSS11SysUpdateButton',
                            id: 'dSS11SysUpdateButton',
                            iconCls: 'icon-package-update',
                            disabled: true,
                            scope: this,
                            handler: this.updateSystem.createDelegate(this)
                        }
                    ],
                    items: [ this.mainGrid ]
                }
            );

            dSS11.SystemUpdatePanel.superclass.initComponent.apply(this, arguments);

            this.on('activate',
                function() 
                {
                    if (this.loaded === false) {
                        this.updateStore.load();
                        this.loaded = true;
                    }
                },
                this);

            this.on('hide',
                function()
                {
                    this.noUpdatesTooltip.hide();
                    this.gotUpdatesTooltip.hide();
                },
                this);

            dSS11.MessageBus.on('refreshsystemupdateview', function() {
                    if (this.isVisible()) {
                        this.refreshList();
                    }
                },
                this);

            this.updateStore.on('load',
                function() 
                {
                    var button = this.getTopToolbar().get('dSS11SysUpdateButton');
                    var count = this.updateStore.getTotalCount();

                    if (count > 0) {
                        this.noUpdatesTooltip.hide();
                        this.noUpdatesTooltip.disable();
                        this.gotUpdatesTooltip.enable();
                        button.enable();
                        this.gotUpdatesTooltip.setTitle(
                                count + " " + 
                                dSS11.config.gt.ngettext("Update", 
                                                    "n% Updates", count) +
                                        " " + _("found"));

                        if (this.isVisible()) {
                            this.gotUpdatesTooltip.show();
                        }
                    } else {
                        button.disable();
                        this.gotUpdatesTooltip.hide();
                        this.gotUpdatesTooltip.disable();
                        this.noUpdatesTooltip.enable();
                        if ((this.fromRefetch === true) && this.isVisible()) {
                            this.noUpdatesTooltip.show();
                            this.fromRefetch = false;
                        }
                    }
                },
                this);

        },
        refreshList: function() 
        {
            this.updateStore.load();
        },
        updateDone: function()
        {
            var msg = _("Your system was successfully updated");
            Ext.Msg.show({
                title: _("Info"),
                msg: msg,
                icon: Ext.MessageBox.INFO,
                buttons: Ext.Msg.OK
            });
            this.refreshList();
        },
        refetchDone: function() 
        {
            this.fromRefetch = true;
            this.refreshList();
        },
        handleRefetch: function()
        {
            var fn = dSS11.util.opkg.createDelegate(this,
                           [ 'update',
                              this.findParentByType('viewport').el,
                              this.refetchDone.createDelegate(this) ]);
            fn();
        },
        updateSystem: function() {
            var fn = dSS11.util.opkg.createDelegate(this,
                           [ 'upgrade',
                              this.findParentByType('viewport').el,
                              this.updateDone.createDelegate(this) ]);
            fn();
        }
    }
);

Ext.reg('dss11systemupdate', dSS11.SystemUpdatePanel);

